@@ -5,6 +5,7 @@ import csv
 import json
 import sys
 import time
+from enum import Enum
 from pathlib import Path
 from types import TracebackType
 from typing import Any
@@ -14,13 +15,14 @@ from typing import TYPE_CHECKING
 import click
 from _pytask.click import ColoredCommand
 from _pytask.config import hookimpl
+from _pytask.config_utils import parse_click_choice
 from _pytask.console import console
 from _pytask.console import format_task_id
 from _pytask.database import db
 from _pytask.exceptions import CollectionError
 from _pytask.exceptions import ConfigurationError
 from _pytask.nodes import FilePathNode
-from _pytask.nodes import MetaTask
+from _pytask.nodes import Task
 from _pytask.outcomes import ExitCode
 from _pytask.outcomes import TaskOutcome
 from _pytask.pluginmanager import get_plugin_manager
@@ -36,6 +38,12 @@ if TYPE_CHECKING:
     from typing import NoReturn
 
 
+class _ExportFormats(Enum):
+    NO = "no"
+    JSON = "json"
+    CSV = "csv"
+
+
 class Runtime(db.Entity):  # type: ignore
     """Record of runtimes of tasks."""
 
@@ -56,7 +64,10 @@ def pytask_parse_config(
 ) -> None:
     """Parse the configuration."""
     config["export"] = get_first_non_none_value(
-        config_from_cli, key="export", default=None
+        config_from_cli,
+        key="export",
+        default=_ExportFormats.NO,
+        callback=parse_click_choice("export", _ExportFormats),
     )
 
 
@@ -69,7 +80,7 @@ def pytask_post_parse(config: dict[str, Any]) -> None:
 
 
 @hookimpl(hookwrapper=True)
-def pytask_execute_task(task: MetaTask) -> Generator[None, None, None]:
+def pytask_execute_task(task: Task) -> Generator[None, None, None]:
     """Attach the duration of the execution to the task."""
     start = time.time()
     yield
@@ -101,9 +112,9 @@ def _create_or_update_runtime(task_name: str, start: float, end: float) -> None:
 @click.command(cls=ColoredCommand)
 @click.option(
     "--export",
-    type=str,
+    type=click.Choice([x.value for x in _ExportFormats]),
     default=None,
-    help="Export the profile in the specified format.",
+    help="Export the profile in the specified format. [dim]\\[default: no][/]",
 )
 def profile(**config_from_cli: Any) -> NoReturn:
     """Show information about tasks like runtime and memory consumption of products."""
@@ -120,7 +131,7 @@ def profile(**config_from_cli: Any) -> NoReturn:
         config = pm.hook.pytask_configure(pm=pm, config_from_cli=config_from_cli)
         session = Session.from_config(config)
 
-    except (ConfigurationError, Exception):
+    except (ConfigurationError, Exception):  # pragma: no cover
         session = Session({}, None)
         session.exit_code = ExitCode.CONFIGURATION_FAILED
         exc_info: tuple[
@@ -148,10 +159,10 @@ def profile(**config_from_cli: Any) -> NoReturn:
 
             console.rule(style="neutral")
 
-        except CollectionError:
+        except CollectionError:  # pragma: no cover
             session.exit_code = ExitCode.COLLECTION_FAILED
 
-        except Exception:
+        except Exception:  # pragma: no cover
             session.exit_code = ExitCode.FAILED
             console.print_exception()
             console.rule(style="failed")
@@ -160,7 +171,7 @@ def profile(**config_from_cli: Any) -> NoReturn:
 
 
 def _print_profile_table(
-    profile: dict[str, dict[str, Any]], tasks: list[MetaTask], config: dict[str, Any]
+    profile: dict[str, dict[str, Any]], tasks: list[Task], config: dict[str, Any]
 ) -> None:
     """Print the profile table."""
     name_to_task = {task.name: task for task in tasks}
@@ -187,11 +198,14 @@ def _print_profile_table(
 
 
 class DurationNameSpace:
+    """A namespace for adding durations to the profile."""
+
     @staticmethod
     @hookimpl
     def pytask_profile_add_info_on_task(
-        tasks: list[MetaTask], profile: dict[str, dict[str, Any]]
+        tasks: list[Task], profile: dict[str, dict[str, Any]]
     ) -> None:
+        """Add the runtime for tasks to the profile."""
         runtimes = _collect_runtimes([task.name for task in tasks])
         for name, duration in runtimes.items():
             profile[name]["Duration (in s)"] = round(duration, 2)
@@ -206,11 +220,14 @@ def _collect_runtimes(task_names: list[str]) -> dict[str, float]:
 
 
 class FileSizeNameSpace:
+    """A namespace for adding the total file size of products to a task."""
+
     @staticmethod
     @hookimpl
     def pytask_profile_add_info_on_task(
-        session: Session, tasks: list[MetaTask], profile: dict[str, dict[str, Any]]
+        session: Session, tasks: list[Task], profile: dict[str, dict[str, Any]]
     ) -> None:
+        """Add the total file size of all products for a task."""
         for task in tasks:
             successors = list(session.dag.successors(task.name))
             if successors:
@@ -255,21 +272,24 @@ def _process_profile(profile: dict[str, dict[str, Any]]) -> dict[str, dict[str,
 
 
 class ExportNameSpace:
+    """A namespace for exporting the profile."""
+
     @staticmethod
     @hookimpl(trylast=True)
     def pytask_profile_export_profile(
         session: Session, profile: dict[str, dict[str, Any]]
     ) -> None:
-        extension = session.config["export"]
+        """Export profiles."""
+        export = session.config["export"]
 
-        if extension == "csv":
+        if export == _ExportFormats.CSV:
             _export_to_csv(profile)
-        elif extension == "json":
+        elif export == _ExportFormats.JSON:
             _export_to_json(profile)
-        elif extension is None:
+        elif export == _ExportFormats.NO:
             pass
-        else:
-            raise ValueError(f"The export option {extension!r} cannot be handled.")
+        else:  # pragma: no cover
+            raise ValueError(f"The export option {export.value!r} cannot be handled.")
 
 
 def _export_to_csv(profile: dict[str, dict[str, Any]]) -> None:
